==> openshift-model-storageversionmigrator-5.10.2-sources.jar: io/fabric8/openshift/api/model/storageversionmigrator/v1alpha1/StorageStateBuilder.java <==
package io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class StorageStateBuilder extends io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateFluentImpl<io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageState,io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateBuilder>{
  public StorageStateBuilder() {
    this(false);
  }
  public StorageStateBuilder(java.lang.Boolean validationEnabled) {
    this(new StorageState(), validationEnabled);
  }
  public StorageStateBuilder(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateFluent<?> fluent) {
    this(fluent, false);
  }
  public StorageStateBuilder(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new StorageState(), validationEnabled);
  }
  public StorageStateBuilder(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateFluent<?> fluent,io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageState instance) {
    this(fluent, instance, false);
  }
  public StorageStateBuilder(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateFluent<?> fluent,io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageState instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public StorageStateBuilder(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageState instance) {
    this(instance,false);
  }
  public StorageStateBuilder(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageState instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageState build() {
    StorageState buildable = new StorageState(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StorageStateBuilder that = (StorageStateBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-storageversionmigrator-6.3.1-sources.jar: io/fabric8/openshift/api/model/storageversionmigrator/v1alpha1/StorageStateBuilder.java <==
package io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class StorageStateBuilder extends StorageStateFluentImpl<StorageStateBuilder> implements VisitableBuilder<StorageState,StorageStateBuilder>{
  public StorageStateBuilder() {
    this(false);
  }
  public StorageStateBuilder(Boolean validationEnabled) {
    this(new StorageState(), validationEnabled);
  }
  public StorageStateBuilder(StorageStateFluent<?> fluent) {
    this(fluent, false);
  }
  public StorageStateBuilder(StorageStateFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new StorageState(), validationEnabled);
  }
  public StorageStateBuilder(StorageStateFluent<?> fluent,StorageState instance) {
    this(fluent, instance, false);
  }
  public StorageStateBuilder(StorageStateFluent<?> fluent,StorageState instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public StorageStateBuilder(StorageState instance) {
    this(instance,false);
  }
  public StorageStateBuilder(StorageState instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  StorageStateFluent<?> fluent;
  Boolean validationEnabled;
  public StorageState build() {
    StorageState buildable = new StorageState(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
